@@ -23,12 +23,10 @@ private slots:
 
     void on_clearButton_clicked();
 
-    void on_removePlaylists_clicked();
 
 signals:
     void closeButtonClicked();
     void clearCurrentClicked();
-    void removePlaylistsButtonClicked();
 
 private:
     Ui::Options *ui;
