@@ -5,6 +5,7 @@ void Reader::run()
     QString audio = this->filename;
     audio.chop(3);
     audio.append("wav");
+    qDebug()<<audio;
     audioFile = new QFile(audio);
     if (!audioFile->open(QIODevice::ReadWrite))
         qDebug()<<"cannot write to file";
@@ -21,7 +22,7 @@ void Reader::run()
 
         myProcess->start(program, arguments);
         myProcess->waitForFinished();
-
+        qDebug()<<"done";
         audioFile->close();
         this->finished();
 
